{% extends 'tom_common/base.html' %}
{% load bootstrap4 %}
{% block title %}Sign up{% endblock %}
{% block content %}
<h2>Sign up</h2>
<form action="{% url 'registration:register' %}" method="POST">
{% csrf_token %}
{% bootstrap_form form %}
{% bootstrap_formset form.user_profile_formset %}
{% buttons %}
  <button type="submit" class="btn btn-primary">
    Register
  </button>
{% endbuttons %}
</form>
<hr/>
<p><em><a target="_blank" href="https://github.com/TOMToolkit/tom_registration">TOM Registration</a> version {{ version }}</em></p>
{% endblock %}
